Method: EnergyPlus::DDYFile#heating
- Defined in:
- lib/energyplus/DDYFile.rb
#heating(typestr) ⇒ Object
untyped enumerations for heating, cooling, and humidification make this an array, the first column of the array is the ep object, the remaining items are the “attributes and tags”
129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/energyplus/DDYFile.rb', line 129 def heating(typestr) search = "Annual Heating " + typestr obj = findObjectByComment(search) puts "[DDYFile] #{File.basename(@path.to_s)} missing heating #{typestr}" if obj.nil? = [] << search.gsub("\\","") << search.gsub("\\","").gsub(" ","_").gsub(".","_").gsub("%","").gsub("=>","_").gsub("__","_") << obj return end |